import urllib.request, json
from endpoints import NEW_EMAIL


def fetch(url):
    user_agent = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7'
    headers = {'User-Agent': user_agent, }
    request = urllib.request.Request(url, None, headers)
    response = urllib.request.urlopen(request)
    return json.loads(response.read().decode('utf-8'))


class Mail(object):
    def __init__(self):
        self.mail = fetch(NEW_EMAIL)['address']

    def get_mail(self):
        return self.mail

    def __str__(self):
        return self.mail


if __name__ == "__main__":
    mail = Mail()
    print(mail.get_mail())


import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="python-10minutemail",
    version="0.0.3",
    description="Python wrapper for 10minutemail.com",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/SauravKanchan/10minutemail",
    author="Saurav Kanchan",
    author_email="sauravnk30@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    py_modules= ["minutemail", "endpoint"],
    package_dir={"": "src"},
    include_package_data=True,
    install_requires=[],
    entry_points={},
)
